@@ -91,7 +91,7 @@
                  (encode-key/value key value stream)))
              object)
     object))
-                 
+
 (defmethod encode ((object vector) &optional (stream *standard-output*))
   (with-aggregate/object (stream #\[ #\])
     (loop for value across object
@@ -122,7 +122,7 @@
                (progn
                  (encode-assoc-key/value key value stream)))))
     object))
-  
+
 (defun encode-plist% (object &optional (stream *standard-output*))
   (with-aggregate/object (stream #\{ #\})
     (loop for (key value) on object by #'cddr
@@ -318,6 +318,26 @@ type for which an ENCODE method is defined."
   (loop for (key value) on elements by #'cddr
         do (encode-object-element key value)))
 
+(defun encode-object-slots (object slots)
+  "For each slot in SLOTS, encode that slot on OBJECT as an object element.
+Equivalent to calling ENCODE-OBJECT-ELEMENT for each slot where the
+key is the slot name, and the value is the (SLOT-VALUE OBJECT slot)"
+  (loop for slot in slots
+     do (encode-object-element (string slot)
+                               (slot-value object slot))))
+
+(define-compiler-macro encode-object-slots (&whole form &environment env object raw-slots)
+  "Compiler macro to allow open-coding with encode-object-slots when slots are literal list."
+  (let ((slots (macroexpand raw-slots env)))
+    (cond
+      ((null slots) nil)
+      ((eq (car slots) 'quote)
+       (setf slots (cadr slots))        ; Get the quoted list
+       `(with-slots ,slots ,object
+          ,@(loop for slot in slots
+               collect `(encode-object-element ,(string slot) ,slot))))
+      (t form))))
+
 (defmacro with-object-element ((key) &body body)
   "Open a new encoding context to encode a JSON object element.  KEY
   is the key of the element.  The value will be whatever BODY
